@@ -50,59 +50,70 @@ private:
 class WP3ContentListener : public WP3Listener, protected WPXContentListener
 {
 public:
-	WP3ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP3SubDocument *> &subDocuments, WPXHLListenerImpl *listenerImpl);
+	WP3ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP3SubDocument *> &subDocuments, WPXDocumentInterface *documentInterface);
 	~WP3ContentListener();
 
 	void startDocument() { WPXContentListener::startDocument(); };
-	void insertCharacter(const uint16_t character);
+	void startSubDocument() { WPXContentListener::startSubDocument(); };
+	void insertCharacter(uint32_t character);
 	void insertTab();
-	void insertTab(const uint8_t tabType, const float tabPosition);
-	void insertBreak(const uint8_t breakType) { WPXContentListener::insertBreak(breakType); };
+	void insertTab(uint8_t tabType, double tabPosition);
+	void insertBreak(uint8_t breakType) { WPXContentListener::insertBreak(breakType); };
 	void insertEOL();
-	void attributeChange(const bool isOn, const uint8_t attribute);
-	void lineSpacingChange(const float lineSpacing) { WPXContentListener::lineSpacingChange(lineSpacing); };
-	void pageMarginChange(const uint8_t /* side */, const uint16_t /* margin */) {};
-	void pageFormChange(const uint16_t /* length */, const uint16_t /* width */, const WPXFormOrientation /* orientation */) {};
-	void marginChange(const uint8_t side, const uint16_t margin);
-	void indentFirstLineChange(const int16_t offset);
-	void setTabs(const bool isRelative, const std::vector<WPXTabStop> tabStops);
-	void columnChange(const WPXTextColumnType columnType, const uint8_t numColumns, const std::vector<float> &columnWidth,
+	void attributeChange(bool isOn, uint8_t attribute);
+	void lineSpacingChange(double lineSpacing) { WPXContentListener::lineSpacingChange(lineSpacing); };
+	void pageMarginChange(uint8_t /* side */, uint16_t /* margin */) {};
+	void pageFormChange(uint16_t /* length */, uint16_t /* width */, WPXFormOrientation /* orientation */) {};
+	void marginChange(uint8_t side, uint16_t margin);
+	void indentFirstLineChange(int16_t offset);
+	void setTabs(bool isRelative, const std::vector<WPXTabStop> tabStops);
+	void columnChange(WPXTextColumnType columnType, uint8_t numColumns, const std::vector<double> &columnWidth,
 					const std::vector<bool> &isFixedWidth);
 	void endDocument() { WPXContentListener::endDocument(); };
+	void endSubDocument() { WPXContentListener::endSubDocument(); };
 
-	void defineTable(const uint8_t position, const uint16_t leftOffset);
-	void addTableColumnDefinition(const uint32_t width, const uint32_t leftGutter, const uint32_t rightGutter,
-					const uint32_t attributes, const uint8_t alignment);
+	void defineTable(uint8_t position, uint16_t leftOffset);
+	void addTableColumnDefinition(uint32_t width, uint32_t leftGutter, uint32_t rightGutter,
+					uint32_t attributes, uint8_t alignment);
 	void startTable();
  	void insertRow();
  	void insertCell();
  	void closeCell();
 	void closeRow();
-	void setTableCellSpan(const uint16_t colSpan, const uint16_t rowSpan);
+	void setTableCellSpan(uint16_t colSpan, uint16_t rowSpan);
 	void setTableCellFillColor(const RGBSColor * cellFillColor);
  	void endTable();
-	void undoChange(const uint8_t undoType, const uint16_t undoLevel);
-	void justificationChange(const uint8_t justification);
+	void undoChange(uint8_t undoType, uint16_t undoLevel);
+	void justificationChange(uint8_t justification);
 	void setTextColor(const RGBSColor * fontColor);
 	void setTextFont(const WPXString &fontName);
-	void setFontSize(const uint16_t fontSize);
+	void setFontSize(uint16_t fontSize);
 	void insertPageNumber(const WPXString &pageNumber);
 	void insertNoteReference(const WPXString &noteReference);
-	void insertNote(const WPXNoteType noteType, WP3SubDocument *subDocument);
-	void headerFooterGroup(const uint8_t headerFooterType, const uint8_t occurenceBits, WP3SubDocument *subDocument);
-	void suppressPage(const uint16_t /* suppressCode */) {};
+	void insertNote(WPXNoteType noteType, const WP3SubDocument *subDocument);
+	void headerFooterGroup(uint8_t headerFooterType, uint8_t occurenceBits, WP3SubDocument *subDocument);
+	void suppressPage(uint16_t /* suppressCode */) {};
 	void backTab();
 	void leftIndent();
-	void leftIndent(const float offset);
+	void leftIndent(double offset);
 	void leftRightIndent();
-	void leftRightIndent(const float offset);
+	void leftRightIndent(double offset);
+	void insertPicture(double height, double width, double verticalOffset, double horizontalOffset, uint8_t leftColumn, uint8_t rightColumn,
+			uint16_t figureFlags, const WPXBinaryData &binaryData);
+	void insertTextBox(double height, double width, double verticalOffset, double horizontalOffset, uint8_t leftColumn, uint8_t rightColumn,
+			uint16_t figureFlags, const WP3SubDocument *subDocument, const WP3SubDocument *caption);
+	void insertWP51Table(double height, double width, double verticalOffset, double horizontalOffset, uint8_t leftColumn, uint8_t rightColumn,
+			uint16_t figureFlags, const WP3SubDocument *subDocument, const WP3SubDocument *caption);
 	
 protected:
-	void _handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice = 0);
+	void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice = 0);
 	void _openParagraph();
 
 	void _flushText();
 	void _changeList() {};
+	
+	void _handleFrameParameters( WPXPropertyList &propList, double height, double width, double verticalOffset, double horizontalOffset, uint8_t leftColumn, uint8_t rightColumn,
+			uint16_t figureFlags );
 
 private:
 	WP3ContentListener(const WP3ContentListener&);
