@@ -30,7 +30,8 @@
 class WP3Header : public WPXHeader
 {
  public:
-	WP3Header(WPXInputStream * input, uint32_t documentOffset, uint8_t productType, uint8_t fileType, uint8_t majorVersion, uint8_t minorVersion, uint16_t documentEncryption);
+	WP3Header(WPXInputStream * input, WPXEncryption *encryption, uint32_t documentOffset, uint8_t productType,
+		uint8_t fileType, uint8_t majorVersion, uint8_t minorVersion, uint16_t documentEncryption);
 	~WP3Header() {};
 };
 #endif /* _WP3HEADER_H  */
