@@ -27,21 +27,25 @@
 
 #include "WPXParser.h"
 
-class WPXHLListenerImpl;
+class WPXDocumentInterface;
 class WP3Listener;
+class WP3ResourceFork;
 
 class WP3Parser : public WPXParser
 {
 public:
-	WP3Parser(WPXInputStream *input, WPXHeader *header);
+	WP3Parser(WPXInputStream *input, WPXHeader *header, WPXEncryption *encryption);
 	~WP3Parser();
 
-	void parse(WPXHLListenerImpl *listenerImpl);
+	void parse(WPXDocumentInterface *documentInterface);
+	void parseSubDocument(WPXDocumentInterface *documentInterface);
 	
-	static void parseDocument(WPXInputStream *input, WP3Listener *listener);
+	static void parseDocument(WPXInputStream *input, WPXEncryption *encryption, WP3Listener *listener);
 
 private:
-	void parse(WPXInputStream *input, WP3Listener *listener);
+	WP3ResourceFork * getResourceFork(WPXInputStream *input, WPXEncryption *encryption);
+
+	void parse(WPXInputStream *input, WPXEncryption *encryption, WP3Listener *listener);
 };
 
 #endif /* WP3PARSER_H */
