@@ -33,7 +33,7 @@
 // returns the part if it successfully creates the part, returns 0 if it can't
 // throws an exception if there is an error
 // precondition: readVal is between 0xC0 and 0xEF
-WP3Part * WP3Part::constructPart(WPXInputStream *input, const uint8_t readVal)
+WP3Part * WP3Part::constructPart(WPXInputStream *input, WPXEncryption *encryption, const uint8_t readVal)
 {	
 	WPD_DEBUG_MSG(("WordPerfect: ConstructPart for group 0x%x\n", readVal));
 	
@@ -41,31 +41,31 @@ WP3Part * WP3Part::constructPart(WPXInputStream *input, const uint8_t readVal)
 	{
 		// single-byte function
 		WPD_DEBUG_MSG(("WordPerfect: constructSingleByteFunction(input, val)\n"));
-		return WP3SingleByteFunction::constructSingleByteFunction(input, readVal);
+		return WP3SingleByteFunction::constructSingleByteFunction(input, encryption, readVal);
 	}      
 	else if (readVal >= (uint8_t)0xC0 && readVal <= (uint8_t)0xCF)
 	{
 		// fixed length multi-byte function
 	
-		if (!WP3FixedLengthGroup::isGroupConsistent(input, readVal))
+		if (!WP3FixedLengthGroup::isGroupConsistent(input, encryption, readVal))
 		{
 			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (fixed length) failed; ignoring this byte\n"));
 			return 0;
 		}
 		WPD_DEBUG_MSG(("WordPerfect: constructFixedLengthGroup(input, val)\n"));
-		return WP3FixedLengthGroup::constructFixedLengthGroup(input, readVal);
+		return WP3FixedLengthGroup::constructFixedLengthGroup(input, encryption, readVal);
 	}      
 	else if (readVal >= (uint8_t)0xD0 && readVal <= (uint8_t)0xEF)
 	{
 		// variable length multi-byte function
 	
-		if (!WP3VariableLengthGroup::isGroupConsistent(input, readVal))
+		if (!WP3VariableLengthGroup::isGroupConsistent(input, encryption, readVal))
 		{
 			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (variable length) failed; ignoring this byte\n"));
 			return 0;
 		}
 		WPD_DEBUG_MSG(("WordPerfect: constructVariableLengthGroup(input, val)\n"));
-		return WP3VariableLengthGroup::constructVariableLengthGroup(input, readVal);
+		return WP3VariableLengthGroup::constructVariableLengthGroup(input, encryption, readVal);
 	}
 
 	WPD_DEBUG_MSG(("WordPerfect: Returning 0 from constructPart\n"));
