@@ -28,7 +28,7 @@
 #include "libwpd_internal.h"
 #include "WP3Listener.h"
 
-WP3SingleByteFunction * WP3SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, uint8_t groupID)
+WP3SingleByteFunction * WP3SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, WPXEncryption * /* encryption */, uint8_t groupID)
 {
 
 	switch (groupID) 
@@ -63,22 +63,22 @@ WP3SingleByteFunction * WP3SingleByteFunction::constructSingleByteFunction(WPXIn
 	default:
 		// should not happen
 		return 0;
-		}
+	}
 }
 
 void WP3HardSpaceFunction::parse(WP3Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xa0);
+	listener->insertCharacter((uint32_t) 0xa0);
 }
 
 void WP3HyphenFunction::parse(WP3Listener *listener)
 {
-	listener->insertCharacter((uint16_t) '-');
+	listener->insertCharacter((uint32_t) '-');
 }
 
 void WP3SoftHyphenFunction::parse(WP3Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xad);
+	listener->insertCharacter((uint32_t) 0xad);
 }
 
 void WP3EOLFunction::parse(WP3Listener *listener)
