@@ -36,8 +36,8 @@ WP3StylesListener::WP3StylesListener(std::list<WPXPageSpan> &pageList, WPXTableL
 	m_currentPage(WPXPageSpan()),
 	m_tableList(tableList), 
 	m_currentTable(0),
-	m_tempMarginLeft(1.0f),
-	m_tempMarginRight(1.0f),
+	m_tempMarginLeft(1.0),
+	m_tempMarginRight(1.0),
 	m_currentPageHasContent(false),
 	m_isSubDocument(false),
 	m_subDocuments(subDocuments),
@@ -52,6 +52,12 @@ void WP3StylesListener::endDocument()
 	setUndoOn(false);
 }
 
+void WP3StylesListener::endSubDocument()
+{	
+	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
+	setUndoOn(false);
+}
+
 void WP3StylesListener::insertBreak(const uint8_t breakType)
 {
 	if (m_isSubDocument)
@@ -76,7 +82,7 @@ void WP3StylesListener::insertBreak(const uint8_t breakType)
 				if (m_pageListHardPageMark == m_pageList.end())
 					m_pageListHardPageMark--;
 			}
-			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0f, 0.0f);
+			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0, 0.0);
 			m_currentPage.setPageSpan(1);
 			m_currentPageHasContent = false;
 			break;
@@ -105,7 +111,7 @@ void WP3StylesListener::pageMarginChange(const uint8_t side, const uint16_t marg
 {
 	if (!isUndoOn()) 
 	{
-		float marginInch = (float)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
+		double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
 		switch(side)
 		{
 			case WPX_TOP:
@@ -126,7 +132,7 @@ void WP3StylesListener::marginChange(const uint8_t side, const uint16_t margin)
 			return; // do not collect L/R margin information in sub documents
 
 		std::list<WPXPageSpan>::iterator Iter;
-		float marginInch = (float)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
+		double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
 		switch(side)
 		{
 			case WPX_LEFT:
@@ -166,8 +172,8 @@ void WP3StylesListener::pageFormChange(const uint16_t length, const uint16_t wid
 {
 	if (!isUndoOn())
 	{
-		float lengthInch = (float)((double)length / (double)WPX_NUM_WPUS_PER_INCH);
-		float widthInch = (float)((double)width / (double)WPX_NUM_WPUS_PER_INCH);
+		double lengthInch = (double)((double)length / (double)WPX_NUM_WPUS_PER_INCH);
+		double widthInch = (double)((double)width / (double)WPX_NUM_WPUS_PER_INCH);
 		if (!m_currentPageHasContent)
 		{
 			m_currentPage.setFormLength(lengthInch);
@@ -206,7 +212,7 @@ void WP3StylesListener::headerFooterGroup(const uint8_t headerFooterType, const
 			if (wpxOccurence != NEVER)
 			{
 				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
-				_handleSubDocument(subDocument, true, tableList);
+				_handleSubDocument(subDocument, WPX_SUBDOCUMENT_HEADER_FOOTER, tableList);
 			}
 			else
 				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, 0, tableList);
@@ -262,13 +268,13 @@ void WP3StylesListener::insertCell()
 	}
 }
 
-void WP3StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter,
+void WP3StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, 
 						WPXTableList tableList, int /* nextTableIndice */)
 {
 	bool oldIsSubDocument = m_isSubDocument;
 	m_isSubDocument = true;
 	bool oldIsUndoOn = isUndoOn();
-	if (isHeaderFooter) 
+	if (subDocumentType == WPX_SUBDOCUMENT_HEADER_FOOTER) 
 	{
 		bool oldCurrentPageHasContent = m_currentPageHasContent;
 		WPXTable * oldCurrentTable = m_currentTable;
