@@ -32,7 +32,8 @@
 class WP3SubDocument : public WPXSubDocument
 {
 public:
-	WP3SubDocument(WPXInputStream *input, const unsigned dataSize);
+	WP3SubDocument(WPXInputStream *input, WPXEncryption *encryption, const unsigned dataSize);
+	WP3SubDocument(uint8_t * streamData, const unsigned dataSize);
 	void parse(WP3Listener *listener) const;
 
 };
