@@ -31,16 +31,16 @@
 class WP3TabGroup : public WP3FixedLengthGroup
 {
 public:
-	WP3TabGroup(WPXInputStream *input, uint8_t groupID);	
+	WP3TabGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);	
 	void parse(WP3Listener *listener);
 	
  protected:
-	void _readContents(WPXInputStream *input);
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 
  private:
  	uint8_t m_subGroup;
 	uint8_t m_modeType;
-	float m_position;
+	double m_position;
 };
 
 #endif /* WP3TABGROUP_H */
