@@ -40,23 +40,25 @@ public:
 	WP42StylesListener(std::list<WPXPageSpan> &pageList, std::vector<WP42SubDocument *> &subDocuments);
 
 	void startDocument() {}
-	void insertCharacter(const uint16_t /* character */) { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void insertTab(const uint8_t /* tabType */, float /* tabPosition */) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void startSubDocument() {}
+	void insertCharacter(uint32_t /* character */) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void insertTab(uint8_t /* tabType */, double /* tabPosition */) { if (!isUndoOn()) m_currentPageHasContent = true; }
 	void insertEOL() { if (!isUndoOn()) m_currentPageHasContent = true; }
- 	void insertBreak(const uint8_t breakType);
-	void attributeChange(const bool /* isOn */, const uint8_t /* attribute */) {}
-	void marginReset(const uint8_t /* leftMargin */, const uint8_t /* rightMargin */) {}
-	void headerFooterGroup(const uint8_t headerFooterDefinition, WP42SubDocument *subDocument);
-	void suppressPageCharacteristics(const uint8_t suppressCode);
+ 	void insertBreak(uint8_t breakType);
+	void attributeChange(bool /* isOn */, uint8_t /* attribute */) {}
+	void marginReset(uint8_t /* leftMargin */, uint8_t /* rightMargin */) {}
+	void headerFooterGroup(uint8_t headerFooterDefinition, WP42SubDocument *subDocument);
+	void suppressPageCharacteristics(uint8_t suppressCode);
 	void endDocument();
+	void endSubDocument();
 
 protected:
-	void _handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice = 0);
+	void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice = 0);
 
 private:
 	WPXPageSpan m_currentPage, m_nextPage;
 	std::vector<WP42SubDocument *> &m_subDocuments;
-	float m_tempMarginLeft, m_tempMarginRight;
+	double m_tempMarginLeft, m_tempMarginRight;
 	bool m_currentPageHasContent;
 	bool m_isSubDocument;
 	std::list<WPXPageSpan>::iterator m_pageListHardPageMark;
