@@ -28,34 +28,37 @@
 #include "WP5FileStructure.h"
 #include "WP5ListFontsUsedPacket.h"
 #include "WP5FontNameStringPoolPacket.h"
-#include "libwpd.h"
+#include "WP5GraphicsInformationPacket.h"
 #include "libwpd_internal.h"
 
-WP5GeneralPacketData::WP5GeneralPacketData(WPXInputStream * /* input */)
+WP5GeneralPacketData::WP5GeneralPacketData()
 {
 }
 
-WP5GeneralPacketData * WP5GeneralPacketData::constructGeneralPacketData(WPXInputStream * input, WP5GeneralPacketIndex *packetIndex)
+WP5GeneralPacketData * WP5GeneralPacketData::constructGeneralPacketData(WPXInputStream * input, WPXEncryption *encryption, WP5GeneralPacketIndex *packetIndex)
 {	       
 	switch (packetIndex->getType())
 	{
 	case WP50_LIST_FONTS_USED_PACKET:
 	case WP51_LIST_FONTS_USED_PACKET:
-		return new WP5ListFontsUsedPacket(input, packetIndex->getID(), packetIndex->getDataOffset(), 
+		return new WP5ListFontsUsedPacket(input, encryption, packetIndex->getID(), packetIndex->getDataOffset(), 
 						packetIndex->getDataSize(), packetIndex->getType());
 	case WP5_FONT_NAME_STRING_POOL_PACKET:
-		return new WP5FontNameStringPoolPacket(input, packetIndex->getID(), packetIndex->getDataOffset(), 
+		return new WP5FontNameStringPoolPacket(input, encryption, packetIndex->getID(), packetIndex->getDataOffset(), 
 							packetIndex->getDataSize());
+	case WP5_GRAPHICS_INFORMATION_PACKET:
+		return new WP5GraphicsInformationPacket(input, encryption, packetIndex->getID(), packetIndex->getDataOffset(),
+			packetIndex->getDataSize());
 	default:
 		return 0;
 	}
 }
 
-void WP5GeneralPacketData::_read(WPXInputStream *input, uint32_t dataOffset, uint32_t dataSize)
+void WP5GeneralPacketData::_read(WPXInputStream *input, WPXEncryption *encryption, uint32_t dataOffset, uint32_t dataSize)
 {
 	input->seek(dataOffset, WPX_SEEK_SET);
 
-	_readContents(input, dataSize);
+	_readContents(input, encryption, dataSize);
 
 	// assert that we haven't surpassed the size of the packet?
 }
