@@ -28,7 +28,7 @@
 #include "WP5Listener.h"
 #include "libwpd_internal.h"
 
-WP5SingleByteFunction * WP5SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, uint8_t groupID)
+WP5SingleByteFunction * WP5SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, WPXEncryption * /* encryption */, uint8_t groupID)
 {
 
 	switch (groupID) 
@@ -59,7 +59,7 @@ WP5SingleByteFunction * WP5SingleByteFunction::constructSingleByteFunction(WPXIn
 	default:
 		// should not happen
 		return 0;
-		}
+	}
 }
 
 void WP5EOLFunction::parse(WP5Listener *listener)
@@ -69,21 +69,21 @@ void WP5EOLFunction::parse(WP5Listener *listener)
 
 void WP5SpaceFunction::parse(WP5Listener *listener)
 {
-	listener->insertCharacter((uint16_t) ' ');
+	listener->insertCharacter((uint32_t) ' ');
 }
 
 void WP5HardSpaceFunction::parse(WP5Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xa0);
+	listener->insertCharacter((uint32_t) 0xa0);
 }
 
 void WP5HyphenFunction::parse(WP5Listener *listener)
 {
-	listener->insertCharacter((uint16_t) '-');
+	listener->insertCharacter((uint32_t) '-');
 }
 
 void WP5SoftHyphenFunction::parse(WP5Listener *listener)
 {
-	listener->insertCharacter((uint16_t) 0xad);
+	listener->insertCharacter((uint32_t) 0xad);
 }
 
