@@ -31,9 +31,9 @@
 class WP5TableEOLGroup : public WP5VariableLengthGroup
 {
  public:
-	WP5TableEOLGroup(WPXInputStream *input);	
+	WP5TableEOLGroup(WPXInputStream *input, WPXEncryption *encryption);	
 	~WP5TableEOLGroup();
-	void _readContents(WPXInputStream *input);
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 	void parse(WP5Listener *listener);
 
 private:
