@@ -31,12 +31,12 @@
 class WP6AttributeGroup : public WP6FixedLengthGroup
 {
  public:
-	WP6AttributeGroup(WPXInputStream *input, uint8_t groupID);	
+	WP6AttributeGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);	
 	virtual void parse(WP6Listener *listener) = 0;
-	const uint8_t getAttribute() const { return m_attribute; }
+	uint8_t getAttribute() const { return m_attribute; }
 	
  protected:
-	void _readContents(WPXInputStream *input);
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 
  private:
 	uint8_t m_attribute;
@@ -45,14 +45,14 @@ class WP6AttributeGroup : public WP6FixedLengthGroup
 class WP6AttributeOnGroup : public WP6AttributeGroup
 {
  public:
-	WP6AttributeOnGroup(WPXInputStream *input, uint8_t groupID);
+	WP6AttributeOnGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);
 	void parse(WP6Listener *listener);
 };
 
 class WP6AttributeOffGroup : public WP6AttributeGroup
 {
  public:
-	WP6AttributeOffGroup(WPXInputStream *input, uint8_t groupID);
+	WP6AttributeOffGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);
 	void parse(WP6Listener *listener);
 };
 
