@@ -543,20 +543,6 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_ARABIC_CHARACTER_SET 13
 #define WP6_ARABIC_SCRIPT_CHARACTER_SET 14
 
-#define WP6_NUM_MULTINATIONAL_CHARACTERS 242
-#define WP6_NUM_PHONETIC_CHARACTERS 145
-#define WP6_NUM_BOX_DRAWING_CHARACTERS 88
-#define WP6_NUM_TYPOGRAPHIC_CHARACTERS 102
-#define WP6_NUM_ICONIC_CHARACTERS 255
-#define WP6_NUM_MATH_SCIENTIFIC_CHARACTERS 238
-#define WP6_NUM_MATH_SCIENTIFIC_EXTENDED_CHARACTERS 229
-#define WP6_NUM_GREEK_CHARACTERS 219
-#define WP6_NUM_HEBREW_CHARACTERS 123
-#define WP6_NUM_CYRILLIC_CHARACTERS 250
-#define WP6_NUM_JAPANESE_CHARACTERS 63
-#define WP6_NUM_ARABIC_CHARACTERS 196
-#define WP6_NUM_ARABIC_SCRIPT_CHARACTERS 220
-
 /* Undo Group */
 #define WP6_UNDO_GROUP_INVALID_TEXT_START 0
 #define WP6_UNDO_GROUP_INVALID_TEXT_END 1
