@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
@@ -35,10 +35,10 @@ typedef struct _RGBSColor RGBSColor;
 class WP6FillStylePacket : public WP6PrefixDataPacket
 {
 public:
-	WP6FillStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
+	WP6FillStylePacket(WPXInputStream *input, WPXEncryption *encryption, int id, uint32_t dataOffset, uint32_t dataSize);
 	~WP6FillStylePacket();
-	void _readContents(WPXInputStream *input);
-	void parse(WP6Listener *listener) const {}
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
+	void parse(WP6Listener * /* listener */) const {}
 	const RGBSColor * getFgColor() const { return &m_fgColor; }
 	const RGBSColor * getBgColor() const { return &m_bgColor; }
 private:              
