@@ -33,35 +33,35 @@
 // returns the part if it successfully creates the part, returns 0 if it can't
 // throws an exception if there is an error
 // precondition: readVal us between 0x80 and 0xFF
-WP6Part * WP6Part::constructPart(WPXInputStream *input, const uint8_t readVal)
+WP6Part * WP6Part::constructPart(WPXInputStream *input, WPXEncryption *encryption, const uint8_t readVal)
 {	
 	WPD_DEBUG_MSG(("WordPerfect: ConstructPart\n"));
 		
 	if (readVal >= (uint8_t)0x80 && readVal <= (uint8_t)0xCF)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: constructSingleByteFunction(input, val=0x%.2x)\n", readVal));
-		return WP6SingleByteFunction::constructSingleByteFunction(input, readVal);
+		return WP6SingleByteFunction::constructSingleByteFunction(input, encryption, readVal);
 	}
 	else if (readVal >= (uint8_t)0xD0 && readVal <= (uint8_t)0xEF)
 	{
-		if (!WP6VariableLengthGroup::isGroupConsistent(input, readVal))
+		if (!WP6VariableLengthGroup::isGroupConsistent(input, encryption, readVal))
 		{
 			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (variable length) failed; ignoring this byte\n"));
 			return 0;
 		}
 		WPD_DEBUG_MSG(("WordPerfect: constructVariableLengthGroup(input, val=0x%.2x)\n", readVal));
-		return WP6VariableLengthGroup::constructVariableLengthGroup(input, readVal);
+		return WP6VariableLengthGroup::constructVariableLengthGroup(input, encryption, readVal);
 	}      
 
 	else if (readVal >= (uint8_t)0xF0 && readVal < (uint8_t)0xFF)
 	{
-		if (!WP6FixedLengthGroup::isGroupConsistent(input, readVal))
+		if (!WP6FixedLengthGroup::isGroupConsistent(input, encryption, readVal))
 		{
 			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (fixed length) failed; ignoring this byte\n"));
 			return 0;
 		}
 		WPD_DEBUG_MSG(("WordPerfect: constructFixedLengthGroup(input, val=0x%.2x)\n", readVal));
-		return WP6FixedLengthGroup::constructFixedLengthGroup(input, readVal);
+		return WP6FixedLengthGroup::constructFixedLengthGroup(input, encryption, readVal);
 	}
 #ifdef DEBUG
 	else
