@@ -37,7 +37,7 @@ class WP6Part
  public:
 	virtual ~WP6Part() {}
 	
-	static WP6Part * constructPart(WPXInputStream *input, const uint8_t readVal);
+	static WP6Part * constructPart(WPXInputStream *input, WPXEncryption *encryption, const uint8_t readVal);
 	virtual void parse(WP6Listener *listener) = 0;
 };
 
