@@ -41,8 +41,8 @@ WP6StylesListener::WP6StylesListener(std::list<WPXPageSpan> &pageList, WPXTableL
 	m_currentPage(),
 	m_tableList(tableList), 
 	m_currentTable(0),
-	m_tempMarginLeft(1.0f),
-	m_tempMarginRight(1.0f),
+	m_tempMarginLeft(1.0),
+	m_tempMarginRight(1.0),
 	m_currentPageHasContent(false),
 	m_isTableDefined(false),
 	m_isSubDocument(false),
@@ -56,6 +56,11 @@ void WP6StylesListener::endDocument()
 	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
 }
 
+void WP6StylesListener::endSubDocument()
+{	
+	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
+}
+
 void WP6StylesListener::insertBreak(const uint8_t breakType)
 {
 	if (m_isSubDocument)
@@ -78,7 +83,7 @@ void WP6StylesListener::insertBreak(const uint8_t breakType)
 				if (m_pageListHardPageMark == m_pageList.end())
 					m_pageListHardPageMark--;
 			}
-			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0f, 0.0f);
+			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0, 0.0);
 			m_currentPage.setPageSpan(1);
 			m_currentPageHasContent = false;
 			break;
@@ -92,11 +97,28 @@ void WP6StylesListener::insertBreak(const uint8_t breakType)
 	}
 }
 
+void WP6StylesListener::pageNumberingChange(const WPXPageNumberPosition pageNumberingPosition, const uint16_t pageNumberFontPointSize, const uint16_t pageNumberFontPID)
+{
+	if (!isUndoOn()) 
+	{
+		m_currentPage.setPageNumberPosition(pageNumberingPosition);
+
+		if (pageNumberFontPID)
+		{
+			WPXString pidFontName = WP6Listener::getFontNameForPID(pageNumberFontPID);
+			if (!!pidFontName)
+				m_currentPage.setPageNumberingFontName(pidFontName);
+		}
+
+		m_currentPage.setPageNumberingFontSize(wpuToFontPointSize(pageNumberFontPointSize));
+	}
+}
+
 void WP6StylesListener::pageMarginChange(const uint8_t side, const uint16_t margin)
 {
 	if (!isUndoOn()) 
 	{
-		float marginInch = (float)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
+		double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
 		switch(side)
 		{
 			case WPX_TOP:
@@ -113,8 +135,8 @@ void WP6StylesListener::pageFormChange(const uint16_t length, const uint16_t wid
 {
 	if (!isUndoOn())
 	{
-		float lengthInch = (float)((double)length / (double)WPX_NUM_WPUS_PER_INCH);
-		float widthInch = (float)((double)width / (double)WPX_NUM_WPUS_PER_INCH);
+		double lengthInch = (double)((double)length / (double)WPX_NUM_WPUS_PER_INCH);
+		double widthInch = (double)((double)width / (double)WPX_NUM_WPUS_PER_INCH);
 		if (!m_currentPageHasContent)
 		{
 			m_currentPage.setFormLength(lengthInch);
@@ -132,7 +154,7 @@ void WP6StylesListener::marginChange(const uint8_t side, const uint16_t margin)
 			return; // do not deal with L/R margins in headers, footer and notes
 
 		std::list<WPXPageSpan>::iterator Iter;
-		float marginInch = (float)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
+		double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
 		switch(side)
 		{
 			case WPX_LEFT:
@@ -191,7 +213,7 @@ void WP6StylesListener::headerFooterGroup(const uint8_t headerFooterType, const
 			WPXTableList tableList; 
 			m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence,
 						((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), tableList);
-			_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), true, tableList);
+			_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), WPX_SUBDOCUMENT_HEADER_FOOTER, tableList);
 		}
 		m_currentPageHasContent = tempCurrentPageHasContent;
 	}
@@ -202,6 +224,10 @@ void WP6StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
 	if (!isUndoOn()) 
 	{			
 		WPD_DEBUG_MSG(("WordPerfect: suppressPageCharacteristics (suppressCode: %u)\n", suppressCode));
+
+		if (suppressCode & WP6_PAGE_GROUP_SUPPRESS_PAGE_NUMBER)
+			m_currentPage.setPageNumberSuppression(true);
+
 		if (suppressCode & WP6_PAGE_GROUP_SUPPRESS_HEADER_A)
 			m_currentPage.setHeadFooterSuppression(WPX_HEADER_A, true);
 		if (suppressCode & WP6_PAGE_GROUP_SUPPRESS_HEADER_B)
@@ -213,6 +239,22 @@ void WP6StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
 	}
 }
 
+void WP6StylesListener::setPageNumber(const uint16_t pageNumber)
+{
+	if (!isUndoOn()) 
+	{			
+		m_currentPage.setPageNumber(pageNumber);
+	}
+}
+
+void WP6StylesListener::setPageNumberingType(const WPXNumberingType pageNumberingType)
+{
+	if (!isUndoOn()) 
+	{			
+		m_currentPage.setPageNumberingType(pageNumberingType);
+	}
+}
+
 void WP6StylesListener::defineTable(const uint8_t /* position */, const uint16_t /* leftOffset */)
 {
 	if (!isUndoOn()) 
@@ -271,11 +313,29 @@ void WP6StylesListener::noteOn(const uint16_t textPID)
 	if (!isUndoOn()) 
 	{
 		m_currentPageHasContent = true; 		
-		_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), false, m_tableList);
+		_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), WPX_SUBDOCUMENT_NOTE, m_tableList);
 	}
 }
 
-void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList,
+void WP6StylesListener::insertTextBox(const WP6SubDocument *subDocument)
+{
+	if (!isUndoOn() && subDocument)
+	{
+		m_currentPageHasContent = true;
+		_handleSubDocument(subDocument, WPX_SUBDOCUMENT_TEXT_BOX, m_tableList);
+	}
+}
+
+void WP6StylesListener::commentAnnotation(const uint16_t textPID)
+{
+	if (!isUndoOn()) 
+	{
+		m_currentPageHasContent = true; 		
+		_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), WPX_SUBDOCUMENT_COMMENT_ANNOTATION, m_tableList);
+	}
+}
+
+void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList,
 						int /* nextTableIndice */)
 {
 	// We don't want to actual insert anything in the case of a sub-document, but we
@@ -289,7 +349,7 @@ void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, co
 		bool oldIsSubDocument = m_isSubDocument;
 		m_isSubDocument = true;
 		WPXTable *oldCurrentTable = m_currentTable;
-		if (isHeaderFooter) 
+		if (subDocumentType == WPX_SUBDOCUMENT_HEADER_FOOTER) 
 		{
 			bool oldCurrentPageHasContent = m_currentPageHasContent;
 			WPXTableList oldTableList = m_tableList;
