@@ -1,6 +1,7 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -28,8 +29,9 @@
 #include "WPXPageSpan.h"
 #include "libwpd_internal.h"
 
-const float WPX_DEFAULT_PAGE_MARGIN_TOP = 1.0f;
-const float WPX_DEFAULT_PAGE_MARGIN_BOTTOM = 1.0f;
+const double WPX_DEFAULT_PAGE_MARGIN_TOP = 1.0;
+const double WPX_DEFAULT_PAGE_MARGIN_BOTTOM = 1.0;
+
 const uint8_t DUMMY_INTERNAL_HEADER_FOOTER = 16;
 
 // precondition: 0 <= headerFooterType <= 3 (i.e.: we don't handle watermarks here)
@@ -48,7 +50,8 @@ WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, con
 	m_type(headerFooterType),
 	m_occurence(occurence),
 	m_internalType(internalType),
-	m_subDocument(subDocument)
+	m_subDocument(subDocument),
+	m_tableList()
 {
 }
 
@@ -61,19 +64,37 @@ WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooter &headerFooter) :
 {
 }
 
+WPXHeaderFooter& WPXHeaderFooter::operator=(const WPXHeaderFooter &headerFooter)
+{
+	m_type = headerFooter.getType();
+	m_occurence = headerFooter.getOccurence();
+	m_internalType = headerFooter.getInternalType();
+	m_subDocument = headerFooter.getSubDocument();
+	m_tableList = headerFooter.getTableList();
+	return *this;
+}
+
 WPXHeaderFooter::~WPXHeaderFooter()
 {
 //	delete m_subDocument;
 }
 
 WPXPageSpan::WPXPageSpan() :
-	m_formLength(11.0f),
+	m_isPageNumberSuppressed(false),
+	m_formLength(11.0),
 	m_formWidth(8.5f),
 	m_formOrientation(PORTRAIT),
-	m_marginLeft(1.0f),
-	m_marginRight(1.0f),
+	m_marginLeft(1.0),
+	m_marginRight(1.0),
 	m_marginTop(WPX_DEFAULT_PAGE_MARGIN_TOP),
 	m_marginBottom(WPX_DEFAULT_PAGE_MARGIN_BOTTOM),
+	m_pageNumberPosition(PAGENUMBER_POSITION_NONE),
+	m_isPageNumberOverridden(false),
+	m_pageNumberOverride(0),
+	m_pageNumberingType(ARABIC),
+	m_pageNumberingFontName(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman"), // EN PAS DEFAULT FONT AAN VOOR WP5/6/etc
+	m_pageNumberingFontSize(12.0/*WP6_DEFAULT_FONT_SIZE*/), // FIXME ME!!!!!!!!!!!!!!!!!!! HELP WP6_DEFAULT_FONT_SIZE
+	m_headerFooterList(),
 	m_pageSpan(1)
 {
 	for (int i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++)
@@ -81,6 +102,7 @@ WPXPageSpan::WPXPageSpan() :
 }
 
 WPXPageSpan::WPXPageSpan(const WPXPageSpan &page) :
+	m_isPageNumberSuppressed(page.getPageNumberSuppression()),
 	m_formLength(page.getFormLength()),
 	m_formWidth(page.getFormWidth()),
 	m_formOrientation(page.getFormOrientation()),
@@ -88,6 +110,12 @@ WPXPageSpan::WPXPageSpan(const WPXPageSpan &page) :
 	m_marginRight(page.getMarginRight()),
 	m_marginTop(page.getMarginTop()),
 	m_marginBottom(page.getMarginBottom()),
+	m_pageNumberPosition(page.getPageNumberPosition()),
+	m_isPageNumberOverridden(page.getPageNumberOverriden()),
+	m_pageNumberOverride(page.getPageNumberOverride()),
+	m_pageNumberingType(page.getPageNumberingType()),
+	m_pageNumberingFontName(page.getPageNumberingFontName()),
+	m_pageNumberingFontSize(page.getPageNumberingFontSize()),
 	m_headerFooterList(page.getHeaderFooterList()),
 	m_pageSpan(page.getPageSpan())
 {
@@ -96,8 +124,9 @@ WPXPageSpan::WPXPageSpan(const WPXPageSpan &page) :
 }
 
 // NB: this is not a literal "clone" function: it is contingent on the side margins that are passed,
-// and suppression variables are not copied
-WPXPageSpan::WPXPageSpan(const WPXPageSpan &page, float paragraphMarginLeft, float paragraphMarginRight) :
+// and suppression and override variables are not copied
+WPXPageSpan::WPXPageSpan(const WPXPageSpan &page, double paragraphMarginLeft, double paragraphMarginRight) :
+	m_isPageNumberSuppressed(false),
 	m_formLength(page.getFormLength()),
 	m_formWidth(page.getFormWidth()),
 	m_formOrientation(page.getFormOrientation()),
@@ -105,6 +134,12 @@ WPXPageSpan::WPXPageSpan(const WPXPageSpan &page, float paragraphMarginLeft, flo
 	m_marginRight(page.getMarginRight()+paragraphMarginRight),
 	m_marginTop(page.getMarginTop()),
 	m_marginBottom(page.getMarginBottom()),
+	m_pageNumberPosition(page.getPageNumberPosition()),
+	m_isPageNumberOverridden(false),
+	m_pageNumberOverride(0),
+	m_pageNumberingType(page.getPageNumberingType()),
+	m_pageNumberingFontName(page.getPageNumberingFontName()),
+	m_pageNumberingFontSize(page.getPageNumberingFontSize()),
 	m_headerFooterList(page.getHeaderFooterList()),
 	m_pageSpan(page.getPageSpan())
 {
@@ -156,18 +191,6 @@ void WPXPageSpan::setHeaderFooter(const WPXHeaderFooterType type, const uint8_t
 	}
 }
 
-// makeConsistent: post-process page spans (i.e.: save this until all page spans are fully parsed)
-// since this is a span, not an individuated page, we have to swap header/footer odd/even paramaters
-// if we're not starting on an odd page
-// ALSO: add a left/right footer to the page, if we have one but not the other (post-processing step)
-void WPXPageSpan::makeConsistent(int startingPageNumber)
-{
-	if (!(startingPageNumber % 2))
-	{
-	// not sure whether this has any use (Fridrich) ?
-	}
-}
-
 void WPXPageSpan::_removeHeaderFooter(WPXHeaderFooterType type, WPXHeaderFooterOccurence occurence)
 {
 	for (std::vector<WPXHeaderFooter>::iterator iter = m_headerFooterList.begin(); iter != m_headerFooterList.end(); iter++) 
@@ -205,6 +228,22 @@ bool operator==(const WPXPageSpan &page1, const WPXPageSpan &page2)
 	    (page1.getMarginTop() != page2.getMarginTop())|| (page1.getMarginBottom() != page2.getMarginBottom()))
 		return false;
 
+	if (page1.getPageNumberPosition() != page2.getPageNumberPosition()) 
+		return false;
+
+	if (page1.getPageNumberSuppression() != page2.getPageNumberSuppression())
+		return false;
+	
+        if (page1.getPageNumberOverriden() != page2.getPageNumberOverriden() || 
+	    page1.getPageNumberOverride() != page2.getPageNumberOverride())
+		return false;
+
+	if (page1.getPageNumberingType() != page2.getPageNumberingType())
+		return false;
+
+	if (page1.getPageNumberingFontName() != page2.getPageNumberingFontName() ||
+	    page1.getPageNumberingFontSize() != page2.getPageNumberingFontSize())
+		return false;
 
 	for (uint8_t i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++) {
 		if (page1.getHeaderFooterSuppression(i) != page2.getHeaderFooterSuppression(i))
