@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
@@ -26,7 +26,6 @@
 
 #ifndef WPXPAGE_H
 #define WPXPAGE_H
-#include "libwpd.h"
 #include "WPXFileStructure.h"
 #include <vector>
 #include "WPXTable.h"
@@ -44,9 +43,10 @@ public:
 			const uint8_t internalType, const WPXSubDocument * subDocument);
 	WPXHeaderFooter(const WPXHeaderFooter &headerFooter);
 	~WPXHeaderFooter();
-	const WPXHeaderFooterType getType() const { return m_type; }
-	const WPXHeaderFooterOccurence getOccurence() const { return m_occurence; }
-	const uint8_t getInternalType() const { return m_internalType; }
+	WPXHeaderFooter& operator=(const WPXHeaderFooter &headerFooter);
+	WPXHeaderFooterType getType() const { return m_type; }
+	WPXHeaderFooterOccurence getOccurence() const { return m_occurence; }
+	uint8_t getInternalType() const { return m_internalType; }
 	const WPXSubDocument * getSubDocument() const { return m_subDocument; }
 	WPXTableList getTableList() const { return m_tableList; }
 
@@ -62,34 +62,45 @@ class WPXPageSpan
 {
 public:
 	WPXPageSpan();
-	WPXPageSpan(const WPXPageSpan &page, float paragraphMarginLeft, float paragraphMarginRight);
+	WPXPageSpan(const WPXPageSpan &page, double paragraphMarginLeft, double paragraphMarginRight);
 	WPXPageSpan(const WPXPageSpan &page);
 	virtual ~WPXPageSpan();
 
-	const bool getHeaderFooterSuppression(const uint8_t headerFooterType) const { if (headerFooterType <= WPX_FOOTER_B) return m_isHeaderFooterSuppressed[headerFooterType]; return false; }
-	const float getFormLength() const { return m_formLength; }
-	const float getFormWidth() const { return m_formWidth; }
-	const WPXFormOrientation getFormOrientation() const { return m_formOrientation; }
-	const float getMarginLeft() const { return m_marginLeft; }
- 	const float getMarginRight() const { return m_marginRight; }
- 	const float getMarginTop() const { return m_marginTop; }
- 	const float getMarginBottom() const { return m_marginBottom; }
-	const int getPageSpan() const { return m_pageSpan; }
+	bool getPageNumberSuppression() const { return m_isPageNumberSuppressed; }
+	bool getHeaderFooterSuppression(const uint8_t headerFooterType) const { if (headerFooterType <= WPX_FOOTER_B) return m_isHeaderFooterSuppressed[headerFooterType]; return false; }
+	double getFormLength() const { return m_formLength; }
+	double getFormWidth() const { return m_formWidth; }
+	WPXFormOrientation getFormOrientation() const { return m_formOrientation; }
+	double getMarginLeft() const { return m_marginLeft; }
+ 	double getMarginRight() const { return m_marginRight; }
+ 	double getMarginTop() const { return m_marginTop; }
+ 	double getMarginBottom() const { return m_marginBottom; }
+	WPXPageNumberPosition getPageNumberPosition() const { return m_pageNumberPosition; }
+	bool getPageNumberOverriden() const { return m_isPageNumberOverridden; }
+	int getPageNumberOverride() const { return m_pageNumberOverride; }
+        WPXNumberingType getPageNumberingType() const { return m_pageNumberingType; }
+        double getPageNumberingFontSize() const { return m_pageNumberingFontSize; }
+        WPXString getPageNumberingFontName() const { return m_pageNumberingFontName; }
+	int getPageSpan() const { return m_pageSpan; }
 	const std::vector<WPXHeaderFooter> & getHeaderFooterList() const { return m_headerFooterList; }
 
 	void setHeaderFooter(const WPXHeaderFooterType type, const uint8_t headerFooterType, const WPXHeaderFooterOccurence occurence, 
 			     const WPXSubDocument * subDocument, WPXTableList tableList);
+	void setPageNumberSuppression(const bool suppress) { m_isPageNumberSuppressed = suppress; }
 	void setHeadFooterSuppression(const uint8_t headerFooterType, const bool suppress) { m_isHeaderFooterSuppressed[headerFooterType] = suppress; }
-	void setFormLength(const float formLength) { m_formLength = formLength; }
-	void setFormWidth(const float formWidth) { m_formWidth = formWidth; }
+	void setFormLength(const double formLength) { m_formLength = formLength; }
+	void setFormWidth(const double formWidth) { m_formWidth = formWidth; }
 	void setFormOrientation(const WPXFormOrientation formOrientation) { m_formOrientation = formOrientation; }
-	void setMarginLeft(const float marginLeft) { m_marginLeft = marginLeft; }
- 	void setMarginRight(const float marginRight) { m_marginRight = marginRight; }
- 	void setMarginTop(const float marginTop) { m_marginTop = marginTop; }
- 	void setMarginBottom(const float marginBottom) { m_marginBottom = marginBottom; }
-	void setPageSpan(const int pageSpan) { m_pageSpan = pageSpan; }
-	
-	void makeConsistent(int startingPageNumber);
+	void setMarginLeft(const double marginLeft) { m_marginLeft = marginLeft; }
+ 	void setMarginRight(const double marginRight) { m_marginRight = marginRight; }
+ 	void setMarginTop(const double marginTop) { m_marginTop = marginTop; }
+ 	void setMarginBottom(const double marginBottom) { m_marginBottom = marginBottom; }
+	void setPageNumberPosition(const WPXPageNumberPosition pageNumberPosition) { m_pageNumberPosition = pageNumberPosition; }
+	void setPageNumber(const int pageNumberOverride) { m_pageNumberOverride = pageNumberOverride; m_isPageNumberOverridden = true; } 
+	void setPageNumberingType(const WPXNumberingType pageNumberingType) { m_pageNumberingType = pageNumberingType; }
+        void setPageNumberingFontSize(const double pageNumberingFontSize) { m_pageNumberingFontSize = pageNumberingFontSize; }
+        void setPageNumberingFontName(const WPXString &pageNumberingFontName) { m_pageNumberingFontName = pageNumberingFontName; }
+        void setPageSpan(const int pageSpan) { m_pageSpan = pageSpan; }
 	
 protected:
 	void _removeHeaderFooter(WPXHeaderFooterType type, WPXHeaderFooterOccurence occurence);
@@ -97,10 +108,17 @@ protected:
 
 private:
 	bool m_isHeaderFooterSuppressed[WPX_NUM_HEADER_FOOTER_TYPES];
-	float m_formLength, m_formWidth;
+	bool m_isPageNumberSuppressed;
+	double m_formLength, m_formWidth;
 	WPXFormOrientation m_formOrientation;
-	float m_marginLeft, m_marginRight;
-	float m_marginTop, m_marginBottom;
+	double m_marginLeft, m_marginRight;
+	double m_marginTop, m_marginBottom;
+	WPXPageNumberPosition m_pageNumberPosition;
+	bool m_isPageNumberOverridden;
+	int m_pageNumberOverride;
+        WPXNumberingType m_pageNumberingType;
+	WPXString m_pageNumberingFontName;
+	double m_pageNumberingFontSize;
 	std::vector<WPXHeaderFooter> m_headerFooterList;
 
 	int m_pageSpan;
